#
# Copyright (c) 2015 Midokura SARL, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import collections

MIDOKURA_KEY_FINGERPRINT = 'BC4E4E90DDA81C21396081CC67B38D3A054314CD'
MIDOKURA_KEY_CONTENT = """-----BEGIN PGP PUBLIC KEY BLOCK-----
Version: GnuPG v1

mI0ETb6aOgEEAMVw8Vnwk+zpDtsc0gSW10JEe48zKr2vpl9tQgWAFOPgOA1NglYM
w/xT6Rns7CrYxPR0cb3DeMFtFdMkfWXO0R6x4yHrozMDY/DpvwgYQclIIbcYYe0p
83nlBp793D2dSq60HWuXJu3oi0wQQuR0/jTmOnjxzCzu5jKdJeXihl95ABEBAAG0
Jk1pZG9rdXJhIChNaWRva3VyYSkgPGluZm9AbWlkb2t1cmEuanA+iLgEEwECACIF
Ak2+mjoCGwMGCwkIBwMCBhUIAgkKCwQWAgMBAh4BAheAAAoJEGezjToFQxTNAp0D
/2c+PLnRFzEXCztXT+05xoO1mPzpm3x2p5ecVPGHR8IxhozlN9DDGDdnvNfMOhi6
nv/G2l86+9Fj8Dz01ne0RZzZHSS1DF/zb6dMYrPJqiT1DXKH0Y73OL/+M7rsutEq
0B/DKhjdBfFPutk3gerEUZPNfIhScE3tnwCnVGJKPQbFuI0ETb6aOgEEANLJK3gm
Xrsp1VKnt663RoxZgoFQgQ6wHaZZWhULTteafjoThX9tj7FidR2+7qJLwpa57M9d
rib4OlbW+rE4PW199/Uqfy86gLv76Q2GZMpzaYB1ZZow0Ny1RTCwh7apkhR/8fCU
pq37aODQ4YwBpZC54iXVKfcntpdJFoObIqXtABEBAAGInwQYAQIACQUCTb6aOgIb
DAAKCRBns406BUMUzfzOBACKx4jChKTAl6HfldOxVN7o8DQpd5rgkHIEj062ym4Z
q5t2v3oaz0H0P2WV66MAhOujgX0V1duZi8fKHdIsdk0nvEa/mV0QS6pEAeZh+dbL
kKyu1J4MSi5l+L+te5XjYBGpoRa3ZGrIR3CkA0oQDCOh312SrcH6Tn9RBPChVSig
zg==
=zF5K
-----END PGP PUBLIC KEY BLOCK-----"""


RELEASES = collections.OrderedDict([
    ('icehouse/mem-1.8', {
        'midonet_repo':
        'http://%s:%s@apt.midokura.com/midonet/v1.8/stable',
        'midonet_openstack_repo':
        'http://%s:%s@apt.midokura.com/openstack/icehouse/stable',
        'midonet_stage':
        'trusty',
        'midonet_key_fingerprint':
        MIDOKURA_KEY_FINGERPRINT,
        'midonet_key_content':
        MIDOKURA_KEY_CONTENT,
        'openstack_release':
        'icehouse',
        'api_version':
        '1.8'
    }),
    ('juno/mem-1.8', {
        'midonet_repo':
        'http://%s:%s@apt.midokura.com/midonet/v1.8/stable',
        'midonet_openstack_repo':
        'http://%s:%s@apt.midokura.com/openstack/juno/stable',
        'midonet_stage':
        'trusty',
        'midonet_key_fingerprint':
        MIDOKURA_KEY_FINGERPRINT,
        'midonet_key_content':
        MIDOKURA_KEY_CONTENT,
        'openstack_release':
        'juno',
        'api_version':
        '1.8'
    }),
    ('juno/mem-1.9', {
        'midonet_repo':
        'http://%s:%s@apt.midokura.com/midonet/v1.9/stable',
        'midonet_openstack_repo':
        'http://%s:%s@apt.midokura.com/openstack/juno/stable',
        'midonet_stage':
        'trusty',
        'midonet_key_fingerprint':
        MIDOKURA_KEY_FINGERPRINT,
        'midonet_key_content':
        MIDOKURA_KEY_CONTENT,
        'openstack_release':
        'juno',
        'api_version':
        '1.9'
    }),
    ('kilo/mem-1.9', {
        'midonet_repo':
        'http://%s:%s@apt.midokura.com/midonet/v1.9/stable',
        'midonet_openstack_repo':
        'http://%s:%s@apt.midokura.com/openstack/kilo/stable',
        'midonet_stage':
        'trusty',
        'midonet_key_fingerprint':
        MIDOKURA_KEY_FINGERPRINT,
        'midonet_key_content':
        MIDOKURA_KEY_CONTENT,
        'openstack_release':
        'kilo',
        'api_version':
        '1.9'
    }),
    ('liberty/mem-1.9', {
        'midonet_repo':
        'http://%s:%s@apt.midokura.com/midonet/v1.9/stable',
        'midonet_openstack_repo':
        'http://%s:%s@apt.midokura.com/openstack/liberty/stable',
        'midonet_stage':
        'trusty',
        'midonet_key_fingerprint':
        MIDOKURA_KEY_FINGERPRINT,
        'midonet_key_content':
        MIDOKURA_KEY_CONTENT,
        'openstack_release':
        'kilo',
        'api_version':
        '1.9'
    }),
    ('juno/midonet-2015.06', {
        'midonet_repo':
        'http://repo.midonet.org/midonet/v2015.06',
        'midonet_openstack_repo':
        'http://repo.midonet.org/openstack-juno',
        'openstack_release':
        'juno'
    }),
    ('kilo/midonet-2015.06', {
        'midonet_repo':
        'http://repo.midonet.org/midonet/v2015.06',
        'midonet_openstack_repo':
        'http://repo.midonet.org/openstack-kilo',
        'openstack_release':
        'kilo'
    }),
    ('liberty/midonet-2015.06', {
        'midonet_repo':
        'http://repo.midonet.org/midonet/v2015.06',
        'midonet_openstack_repo':
        'http://repo.midonet.org/openstack-kilo',
        'openstack_release':
        'kilo'
    }),
])


def config(midonet_rel=None, user=None, password=None):
    cfg = {}

    if midonet_rel in (None, '', 'latest'):
        cfg['midonet_latest'] = True
    else:
        if midonet_rel not in RELEASES:
            raise ValueError('Unrecognized release %s' % midonet_rel)
        cfg = dict(RELEASES[midonet_rel])
        mem = midonet_rel.split('/')[1].startswith('mem')
        if mem:
            if user is None or password is None:
                raise ValueError('MEM releases require credentials')
            cfg['midonet_repo'] = cfg['midonet_repo'] % (user, password)
            cfg['midonet_openstack_repo'] = cfg['midonet_openstack_repo'] % (
                user, password)

    return cfg
