#!/usr/bin/env python
# vim: tabstop=4 shiftwidth=4 softtabstop=4 filetype=python
#
# Copyright (c) 2015 Midokura SARL, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from charmhelpers.contrib.hahelpers import cluster
from charmhelpers.contrib.network import ip
from charmhelpers.core import hookenv


def get_ip():
    """Gets vip if defined, public-address otherwise."""
    vip = hookenv.config('vip')
    if vip and cluster.is_clustered():
        ip = vip
    else:
        ip = hookenv.unit_get('public-address')
    return ip


def get_iface():
    """Gets the ha interface to use."""
    cluster_config = cluster.get_hacluster_config()
    return (ip.get_iface_for_address(cluster_config['vip']) or
            hookenv.config('vip_iface'))


def urls():
    """Returns a dict with public_url, admin_url and internal_url."""
    vip = hookenv.config('vip')
    clustered = cluster.is_clustered()
    urls = {}
    if vip and clustered:
        vip_url = 'http://{}:{}'.format(vip, hookenv.config('api_port'))
        urls['public_url'] = urls['admin_url'] = urls['internal_url'] = vip_url
    else:
        urls['public_url'] = 'http://{}:{}'.format(
            hookenv.unit_get('public-address'), hookenv.config('api_port'))
        urls['admin_url'] = 'http://{}:{}'.format(
            hookenv.unit_get('private-address'), hookenv.config('api_port'))
        urls['internal_url'] = 'http://{}:{}'.format(
            hookenv.unit_get('private-address'), hookenv.config('api_port'))

    return urls
